package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsPersonnelMapper;
import com.steerinfo.dil.mapper.RmsShipperMapper;
import com.steerinfo.dil.model.RmsPersonnel;
import com.steerinfo.dil.model.RmsShipper;
import com.steerinfo.dil.service.IRmsPersonnelService;
import com.steerinfo.dil.util.DataChange;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsPersonnel服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-22 06:01
 * 类描述
 * 修订历史：
 * 日期：2021-10-22
 * 作者：HuJieHuan
 * 参考：
 * 描述：RmsPersonnel服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "rmsPersonnelService")
public class RmsPersonnelServiceImpl implements IRmsPersonnelService {

    @Autowired
    private RmsPersonnelMapper rmsPersonnelMapper;
    @Autowired
    RmsShipperMapper rmsShipperMapper;

    /**
     * 操作人员信息
     * @param mapVal
     * @return
     */
    @Override
    public int operationPersonnel(Map<String, Object> mapVal) {
        // 得到金蝶人员管理主键id
        Integer EASPersonnelIdValue = (Integer) mapVal.get("EASPersonnelId");
        BigDecimal EASPersonnelId = new BigDecimal(EASPersonnelIdValue);
        // 得到人员工号
        String personnelJobNumber = (String) mapVal.get("personnelJobNumber");
        // 得到人员姓名
        String personnelName = (String) mapVal.get("personnelName");
        // 得到数据状态
        Integer dataStatus = (Integer) mapVal.get("dataStatus");
        RmsPersonnel rmsPersonnel = new RmsPersonnel();
//        rmsPersonnel.setEasPersonnelId(EASPersonnelId);
        rmsPersonnel.setPersonnelJobNumber(personnelJobNumber);
        rmsPersonnel.setPersonnelName(personnelName);
        BigDecimal deleted = new BigDecimal(0);
        Map<String,Object> map = new HashMap<>();
        map.put("easPersonnelId",EASPersonnelId);
        map.put("deleted",deleted);
        int result = 0;
        List<RmsPersonnel> rmsPersonnels = rmsPersonnelMapper.selectByParameters(map);
        // 新增
        if (rmsPersonnels.size() == 0) {
            BigDecimal personnelId = rmsPersonnelMapper.getPersonnelId();
            rmsPersonnel.setPersonnelId(personnelId);
            rmsPersonnel.setDeleted(deleted);
            result = rmsPersonnelMapper.insertSelective(rmsPersonnel);
        }
        // 修改
        if (rmsPersonnels.size() != 0 && dataStatus == 2) {
            RmsPersonnel rmsPersonnel1 = rmsPersonnels.get(0);
            rmsPersonnel.setPersonnelId(rmsPersonnel1.getPersonnelId());
            result = rmsPersonnelMapper.updateByPrimaryKeySelective(rmsPersonnel);
        }
        // 逻辑删除
        if (rmsPersonnels.size() != 0 && dataStatus == 3) {
            RmsPersonnel rmsPersonnel1 = rmsPersonnels.get(0);
            rmsPersonnel.setPersonnelId(rmsPersonnel1.getPersonnelId());
            rmsPersonnel.setDeleted(new BigDecimal(1));
            result = rmsPersonnelMapper.updateByPrimaryKeySelective(rmsPersonnel);
        }
        return result;
    }

    /**
     * 展示人员信息列表
     * @param mapVal
     * @return
     */
    @Override
    public List<Map<String, Object>> getPersonnelList(Map<String, Object> mapVal) {
        return rmsPersonnelMapper.getPersonnelList(mapVal);
    }



    /**
     * 添加人员信息
     * @param map
     * @return
     */
    @Override
    public int insertPersonnel(Map<String,Object> map) {
        RmsPersonnel rmsPersonnel=new RmsPersonnel();
        String personnelSsoId = (String) map.get("personnelSsoId");
        String personnelTeam = (String) map.get("personnelTeam");
        String personnelShifts =(String) map.get("personnelShifts");
        String userId =(String) map.get("userId");
        String concatTelephone =(String) map.get("ConcatTelephone");
        String personnelJobNumber = (String) map.get("personnelJobNumber");
        String personnelPost =(String) map.get("personnelPost");
        String personnelName = (String) map.get("personnelName");
        BigDecimal personnelDepartmentId = DataChange.dataToBigDecimal(map.get("personnelDepartmentId"));
        int i=0;
        //判断用户是否存在系统
        BigDecimal personnelId = rmsPersonnelMapper.getPersonnelIdByJobNumber(map);
        if (personnelId!=null&&!"null".equals(personnelId)&&personnelId.intValue()!=0){
           return  -1;
        }else {
            //执行新增
            rmsPersonnel.setPersonnelId(rmsPersonnelMapper.getPersonnelId());
            rmsPersonnel.setPersonnelJobNumber(personnelJobNumber);
            rmsPersonnel.setPersonnelContactNumber(concatTelephone);
            rmsPersonnel.setPersonnelName(personnelName);
            rmsPersonnel.setPersonnelTeam(personnelTeam);
            rmsPersonnel.setPersonnelPost(personnelPost);
            rmsPersonnel.setPersonnelDepartmentId(personnelDepartmentId);
            rmsPersonnel.setPersonnelSsoId(personnelSsoId);
            rmsPersonnel.setPersonnelShifts(personnelShifts);
            rmsPersonnel.setInsertUsername(userId);
            rmsPersonnel.setInsertTime(new Date());
            i+= rmsPersonnelMapper.insertSelective(rmsPersonnel);
        }
        return i;
    }

    /**
     * 修改人员信息,根据id值
     * @param
     * @return
     */
    @Override
    public int updatePersonnel(RmsPersonnel rmsPersonnel) {
        rmsPersonnel.setUpdateUsername("admin");
        rmsPersonnel.setUpdateTime(new Date());
        return rmsPersonnelMapper.updateByPrimaryKeySelective(rmsPersonnel);
    }

    /**
     * 根据id逻辑删除人员信息
     * @param id
     * @return
     */
    @Override
    public int deletePersonnel(BigDecimal id) {
        return rmsPersonnelMapper.updateByPersonnelId(id);
    }

    /**
     * 根据id值获取详细人员信息
     * @param id
     * @return
     */
    @Override
    public List<Map<String, Object>> getPersonnelById(BigDecimal id) {
        return rmsPersonnelMapper.selectPersonnelById(id);
    }

    /**
     * 获取托运人id
     * @return
     */
    @Override
    public List<Map<String, Object>> getShipperId() {
        return rmsPersonnelMapper.getShipperId();
    }

    /**
     * 得到二级部门下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getSecondShipper() {
        return rmsPersonnelMapper.getSecondShipper();
    }

    /**
     * 得到三级部门下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getThirdShipper(BigDecimal shipperId) {
        return rmsPersonnelMapper.getThirdShipper(shipperId);
    }

    /**
     * 新增人员权限
     * @param map
     * @return
     */
    @Override
    public int addPersonnel(Map<String,Object> map) {
        RmsPersonnel rmsPersonnel=new RmsPersonnel();
        String personnelSsoId = (String) map.get("personnelSsoId");
        String personnelTeam = (String) map.get("personnelTeam");
        String personnelShifts =(String) map.get("personnelShifts");
        String userId =(String) map.get("userId");
        String concatTelephone =(String) map.get("ConcatTelephone");
        String personnelJobNumber = (String) map.get("personnelJobNumber");
        String personnelPost =(String) map.get("personnelPost");
        String personnelName = (String) map.get("personnelName");
        BigDecimal personnelDepartmentId = DataChange.dataToBigDecimal(map.get("personnelDepartmentId"));
        int i=0;
        //判断用户是否存在系统
        BigDecimal personnelId = rmsPersonnelMapper.getPersonnelIdByJobNumber(map);
        if (personnelId!=null&&!"null".equals(personnelId)&&personnelId.intValue()!=0){
            return  -1;
        }else {
            //执行新增
            rmsPersonnel.setPersonnelId(rmsPersonnelMapper.getPersonnelId());
            rmsPersonnel.setPersonnelJobNumber(personnelJobNumber);
            rmsPersonnel.setPersonnelContactNumber(concatTelephone);
            rmsPersonnel.setPersonnelName(personnelName);
            rmsPersonnel.setPersonnelTeam(personnelTeam);
            rmsPersonnel.setPersonnelPost(personnelPost);
            rmsPersonnel.setPersonnelDepartmentId(personnelDepartmentId);
            rmsPersonnel.setPersonnelSsoId(personnelSsoId);
            rmsPersonnel.setPersonnelShifts(personnelShifts);
            rmsPersonnel.setInsertUsername(userId);
            rmsPersonnel.setInsertTime(new Date());
            rmsPersonnel.setDeleted(new BigDecimal(0));
            i+= rmsPersonnelMapper.insertSelective(rmsPersonnel);
        }
        return i;
    }

    /**
     * 工号
     * @param personnelJobNumber
     * @return
     */
    public Integer isInHere(String personnelJobNumber) {
        Integer result = rmsPersonnelMapper.selectByParametersPersonnelJobNumber(personnelJobNumber);
        return result;
    }

    /**
     * 查询SSO主键和机构编码
     * @param shipperId
     * @return
     */
    @Override
    public Map<String, Object> getShipperMap(BigDecimal shipperId) {
        return rmsPersonnelMapper.getShipperMap(shipperId);
    }

}
